LED On/Off
------------

Control an LED with Matter:

.. literalinclude:: ../examples/circuitmatter_simpletest.py
    :caption: examples/circuitmatter_simpletest.py
    :linenos:

NeoPixel
------------

Control an RGB LED with Matter:

.. literalinclude:: ../examples/one_rgb_light.py
    :caption: examples/one_rgb_light.py
    :linenos:

Two On/Off LEDs
----------------

Control two LEDs with Matter:

.. literalinclude:: ../examples/two_onoff_led.py
    :caption: examples/two_onoff_led.py
    :linenos:

Record and Replay On/Off LED
----------------------------

Record and replay LED on/off state with Matter:

.. literalinclude:: ../examples/replay.py
    :caption: examples/replay.py
    :linenos:


Record and Replay RGB LED
----------------------------

Record and replay RGB LED state with Matter:

.. literalinclude:: ../examples/replay_rgb_light.py
    :caption: examples/replay_rgb_light.py
    :linenos:
